==> restsql-0.1.21.tar.gz: restsql-0.1.21/restsql/impalet.py <==
import time
from impala.dbapi import connect
from peewee import Database, Context


class ImpalaClient(object):
    def __init__(self, host, port=21050, database=None):
        self.host = host
        self.port = int(port or 21050)
        self.database = database
        print("ImpalaClient, host: %s, port: %s" % (self.host, self.port))
        self.conn = None

    def get_conn(self):
        return connect(host=self.host, port=self.port, database=self.database)

    def run_sql(self, sql):
        start = time.time()
        conn = self.get_conn()
        cursor = conn.cursor()
        print("ImpalaClient, run sql:", sql)
        if isinstance(sql, tuple):
            sql_rep = sql[0].replace("?", "{}")
            cursor.execute(sql_rep.format(*sql[1]))
        else:
            cursor.execute(sql)
        table_description = cursor.description
        results = cursor.fetchall()
        cursor.close()
        records = ImpalaClient.parse_records(results, table_description)
        print("ImpalaClient, get records: %s, sql: %s, cost: %s sec." % (len(records), sql, time.time() - start))
        return records

    @staticmethod
    def parse_records(results, description):
        records = []
        for row in results:
            record = {}
            for index, value in enumerate(row):
                record[description[index][0]] = value
            records.append(record)
        return records


class ImpalaContext(Context):
    def __init__(self, **settings):
        print("setting", settings)
        settings["quote"] = "``"
        super(ImpalaContext, self).__init__(**settings)


class ImpalaDatabase(Database):
    context_class = ImpalaContext

    def init(self, database, **kwargs):
        super(ImpalaDatabase, self).init(database, **kwargs)

==> restsql-0.1.30.tar.gz: restsql-0.1.30/restsql/impalet.py <==
import time
from impala.dbapi import connect
from peewee import Database, Context


class ImpalaClient(object):
    def __init__(self, host, port=21050, database=None):
        self.host = host
        self.port = int(port or 21050)
        self.database = database
        self.conn = None

    def get_conn(self):
        return connect(host=self.host, port=self.port, database=self.database)

    def run_sql(self, sql):
        start = time.time()
        conn = self.get_conn()
        cursor = conn.cursor()
        print("ImpalaClient: Run sql {}".format(sql))
        if isinstance(sql, tuple):
            sql_rep = sql[0].replace("?", "{}")
            cursor.execute(sql_rep.format(*sql[1]))
        else:
            cursor.execute(sql)
        table_description = cursor.description
        results = cursor.fetchall()
        cursor.close()
        records = ImpalaClient.parse_records(results, table_description)
        print("ImpalaClient: Get records: %s, sql: %s, cost: %s sec." % (len(records), sql, time.time() - start))
        return records

    @staticmethod
    def parse_records(results, description):
        records = []
        for row in results:
            record = {}
            for index, value in enumerate(row):
                record[description[index][0]] = value
            records.append(record)
        return records


class ImpalaContext(Context):
    def __init__(self, **settings):
        settings["quote"] = "``"
        super(ImpalaContext, self).__init__(**settings)


class ImpalaDatabase(Database):
    context_class = ImpalaContext

    def init(self, database, **kwargs):
        super(ImpalaDatabase, self).init(database, **kwargs)
